@@ -352,6 +352,9 @@
 #define __NR_sched_setattr	351
 #define __NR_sched_getattr	352
 #define __NR_renameat2		353
+#define __NR_seccomp		354
+#define __NR_getrandom		355
+#define __NR_memfd_create	356
 
 
 /* Repeated with SYS_ prefix */
@@ -710,3 +713,6 @@
 #define SYS_sched_setattr	351
 #define SYS_sched_getattr	352
 #define SYS_renameat2		353
+#define SYS_seccomp		354
+#define SYS_getrandom		355
+#define SYS_memfd_create	356
