@@ -4,8 +4,7 @@
 struct stat
 {
 	dev_t st_dev;
-	int __st_dev_padding;
-	long __st_ino_truncated;
+	ino_t st_ino;
 	mode_t st_mode;
 	nlink_t st_nlink;
 	uid_t st_uid;
@@ -19,5 +18,5 @@ struct stat
 	struct timespec st_atim;
 	struct timespec st_mtim;
 	struct timespec st_ctim;
-	ino_t st_ino;
+	unsigned __unused[2];
 };
