@@ -1,7 +1,7 @@
 static inline struct pthread *__pthread_self()
 {
 	struct pthread *self;
-	__asm__ __volatile__ ("movq %%fs:0,%0" : "=r" (self) );
+	__asm__ __volatile__ ("mov %%fs:0,%0" : "=r" (self) );
 	return self;
 }
 
